@@ -9,7 +9,7 @@
 
 #include "mew.h"
 
-private char version_message[] = "version 5.1 20060327 Kazu Yamamoto";
+private char version_message[] = "version 5.2 20060727 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 # include <sys/types.h>
@@ -885,7 +885,7 @@ private FILE *
 exec_getfile(char **filename, char **foldername)
 {
 	FILE *fp;
-	char *p, *q;
+	char *p, *q, *r;
 	int c;
 
 	*foldername = Current_folder;
@@ -910,17 +910,22 @@ exec_getfile(char **filename, char **foldername)
 		if (isdigit((unsigned char)*p) == 0) continue;
 		*filename = p;
 		while (isdigit((unsigned char)*p)) p++;
-		if (STRCMP(p, Suffix)==0)
+		if (STRCMP(p, Suffix)==0) {
+			r = p;
 			p = p + Suffix_len;
+		} else
+			r = NULL;
 		*p = NUL;
 		fp = fopen(*filename, FDREAD);
-		if (fp != NULL) return fp;
-		/* incm? */
-		if (strlen(*filename) + Suffix_len >= sizeof(Buf_filenm))
-			warn_exit("file name is too long.");
-		strncat(p, Suffix, Suffix_len);
-		fp = fopen(*filename, FDREAD);
-		if (fp != NULL) return fp;
+		if (fp != NULL) {
+			if (r != NULL) *r = NUL;
+			return fp;
+		}
+		if (r != NULL) {
+			*r = NUL;
+			fp = fopen(*filename, FDREAD);
+			if (fp != NULL) return fp;
+		}
 	}
 	return NULL;
 }
