@@ -341,7 +341,7 @@ returned."
       (when (mew-addrbook-insert-file
 	     mew-addrbook-file mew-addrbook-comment-regex 'unquote)
 	(goto-char (point-min))
-	(while (re-search-forward "^ ?\\([^ \n:]+\\) ?\\(:?\\) ?\\([^ \n]+\\)" nil t)
+	(while (re-search-forward "^ ?\\([^ \n:]+\\) ?\\(:?\\) ?\\([^ \t\n]+\\)" nil t)
 	  (setq alias (mew-addrbook-strsafe (mew-match-string 1)))
 	  (setq colon (mew-match-string 2))
 	  (setq addrs (mew-addrbook-strsafe (mew-match-string 3)))
@@ -563,7 +563,7 @@ reflected."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2006 Mew developing team.
+;; Copyright (C) 1999-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
