@@ -713,6 +713,36 @@ Input decryptors' addresses."
 	 syntax (append privacy smime-sign))
 	(mew-encode-syntax-print mew-encode-syntax)))))))
 
+(defun mew-attach-smime-enc ()
+  "Put the 'SE' mark to encrypt with S/MIME in attachment. 
+Input decryptors' addresses."
+  (interactive)
+  (cond
+   ((not (mew-attach-not-line0-1-dot))
+    (message "Cannot S/MIME encrypt here"))
+   ((null mew-smime-ver)
+    (message "%s does not exist" mew-prog-smime))
+   (t
+    (let* ((nums (mew-syntax-nums))
+	   (syntax (mew-syntax-get-entry mew-encode-syntax nums))
+	   (privacy (mew-syntax-get-privacy syntax))
+	   (towhom (mew-header-parse-address-list mew-destination:-list))
+	   (smime-enc (mew-pcdb-ct (mew-pcdb-by-service 'smime-encryption))))
+      (cond
+       ((>= (length privacy) 2)
+	(message "Too many marks"))
+       ((member (car smime-enc) privacy) ;; xxx hard coding
+	(message "Already marked"))
+       (t
+	;; ask towhom before set privacy for C-g
+	(if towhom
+	    (setq towhom (mew-input-address "To (%s): " (mew-join "," towhom)))
+	  (setq towhom (mew-input-address "To: ")))
+	;; towhom is already canonicalized.
+	(mew-syntax-set-privacy 
+	 syntax (append privacy smime-enc))
+	(mew-syntax-set-decrypters syntax towhom)
+	(mew-encode-syntax-print mew-encode-syntax)))))))
 ;;
 ;; find commands
 ;;
@@ -778,7 +808,7 @@ Input decryptors' addresses."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2006 Mew developing team.
+;; Copyright (C) 1996-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
